@@ -1,7 +1,9 @@
-# $Id: exonerate.pm 11480 2007-06-14 14:16:21Z sendu $
+# $Id: exonerate.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::SearchIO::exonerate
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Jason Stajich <jason-at-bioperl.org>
 #
 # Copyright Jason Stajich
@@ -31,7 +33,7 @@ Bio::SearchIO::exonerate - parser for Exonerate
 
 This is a driver for the SearchIO system for parsing Exonerate (Guy
 Slater) output.  You can get Exonerate at
-http://cvsweb.sanger.ac.uk/cgi-bin/cvsweb.cgi/exonerate/?cvsroot=Ensembl
+http://www.ebi.ac.uk/~guy/exonerate/
 [until Guy puts up a Web reference,publication for it.]).
 
 An optional parameter -min_intron is supported by the L<new>
@@ -48,6 +50,7 @@ The GFF that comes from exonerate is still probably a better way to go
 if you are doing protein2genome or est2genome mapping.
 For example you can see this script:
 
+### TODO: Jason, this link is dead, do we have an updated one?
 http://fungal.genome.duke.edu/~jes12/software/scripts/process_exonerate_gff3.perl.txt
 
 If your report contains both CIGAR and VULGAR lines only the first one
@@ -78,6 +81,17 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
@@ -237,7 +251,7 @@ sub next_result{
 	   $self->{'_seencigar'} = 0;
 	   $self->{'_vulgar'}    = 0;
        } elsif(  s/^vulgar:\s+(\S+)\s+         # query sequence id
-		 (\d+)\s+(\d+)\s+([\-\+])\s+   # query start-end-strand
+		 (\d+)\s+(\d+)\s+([\-\+\.])\s+ # query start-end-strand
 		 (\S+)\s+                      # target sequence id
 		 (\d+)\s+(\d+)\s+([\-\+])\s+   # target start-end-strand
 		 (\d+)\s+                      # score
