@@ -1,7 +1,9 @@
-# $Id: Entry.pm 10525 2006-09-26 22:03:22Z sendu $
+# $Id: Entry.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # bioperl module for Bio::Structure::Entry
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Kris Boulez <kris.boulez@algonomics.com>
 #
 # Copyright Kris Boulez
@@ -38,6 +40,17 @@ of the Bioperl mailing lists.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
