@@ -1,6 +1,8 @@
-# $Id: SeqDiff.pm 11480 2007-06-14 14:16:21Z sendu $
+# $Id: SeqDiff.pm 16123 2009-09-17 12:57:27Z cjfields $
 # bioperl module for Bio::Variation::SeqDiff
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
 #
 # Copyright Heikki Lehvaslaiho
@@ -66,6 +68,17 @@ Bioperl mailing lists  Your participation is much appreciated.
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
